isProtected property
Define se a coluna que recebe o resultado (sourceTargetColumn) será protegida automaticamente contra edição manual no Google Sheets. (Padrão: true)
Implementation
final bool isProtected;
Define se a coluna que recebe o resultado (sourceTargetColumn) será protegida automaticamente contra edição manual no Google Sheets. (Padrão: true)
final bool isProtected;