GoogleSheetsDatabase class

Constructors

GoogleSheetsDatabase()
factory

Properties

api ↔ SheetsApi?
getter/setter pair
cacheTime Duration
getter/setter pair
foreignKeys List<ForeignKey>?
getter/setter pair
formulas List<Formula>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spreadsheetId String?
getter/setter pair

Methods

buildCascadeDeleteIndices(String sheetName, List<String> idsToDelete, {Set<String>? visited}) Future<Map<int, Set<int>>>
Constrói de forma recursiva todas as requisições de deleção para os filhos (e netos) caso o onDeleteCascade esteja ativado no ForeignKey. Retorna um Map agrupando por sheetId (GID) um Set de índices de linha únicos a deletar.
initialize({dynamic httpClient, SheetsApi? injectedSheetsApi, DriveApi? injectedDriveApi, required String fileName, required Map<String, List<String>> structure, List<Formula>? formulas, List<ForeignKey>? foreignKeys, Duration cacheTime = const Duration(seconds: 0)}) Future<void>
Inicializa a base de dados
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reapplyFormulas() Future<void>
Restaura as fórmulas e foreign keys. Útil para ser chamado após deleção de linhas que podem ter apagado a linha 2 (onde as fórmulas residem).
repo(String sheetName) SheetORM
toString() String
A string representation of this object.
inherited
updateForeignKey(SheetsApi api, List<ForeignKey>? foreignKeyConfigs) Future<void>
Atualiza as foreign keys na planilha

Operators

operator ==(Object other) bool
The equality operator.
inherited