Formula class
Properties
-
formula
↔ String
-
Formula a ser aplicada (exemplo: "=SUM(A1:B1)")
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isProtected
→ bool
-
final
-
range
↔ String
-
Colunas a serem aplicadas (exemplo: "A1:B1")
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sheet
↔ String
-
Tabela a ser aplicada (exemplo: "Sheet1")
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited